Module blaxel.models.template
=============================

Classes
-------

`Template(default_branch: blaxel.types.Unset | str = <blaxel.types.Unset object>, description: blaxel.types.Unset | str = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, sha: blaxel.types.Unset | str = <blaxel.types.Unset object>, topics: blaxel.types.Unset | list[str] = <blaxel.types.Unset object>, url: blaxel.types.Unset | str = <blaxel.types.Unset object>, variables: blaxel.types.Unset | list['TemplateVariable'] = <blaxel.types.Unset object>)`
:   Blaxel template
    
    Attributes:
        default_branch (Union[Unset, str]): Default branch of the template
        description (Union[Unset, str]): Description of the template
        name (Union[Unset, str]): Name of the template
        sha (Union[Unset, str]): SHA of the variable
        topics (Union[Unset, list[str]]): Topic of the template
        url (Union[Unset, str]): URL of the template
        variables (Union[Unset, list['TemplateVariable']]): Variables of the template
    
    Method generated by attrs for class Template.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `default_branch`
    :

    `description`
    :

    `name`
    :

    `sha`
    :

    `topics`
    :

    `url`
    :

    `variables`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :